# Generated by Django 3.1.7 on 2021-03-13 19:00

from django.db import migrations
import django_jsonfield_backport.models
import notifications.fields


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0001_squashed_0010_notification_channels'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='channels',
            field=notifications.fields.ListField(max_length=200),
        ),
        migrations.AlterField(
            model_name='notification',
            name='extra_data',
            field=django_jsonfield_backport.models.JSONField(default=dict),
        ),
    ]
