# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-07-18 15:39
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='source',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),  # noqa
        ),
        migrations.AlterField(
            model_name='notification',
            name='source_display_name',
            field=models.CharField(max_length=150, null=True),
        ),
    ]
