# Generated by Django 2.0 on 2017-12-28 20:07

from django.db import migrations
import notifications.fields


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0007_auto_20171006_0126'),
    ]

    operations = [
        migrations.AddField(
            model_name='notification',
            name='extra_data',
            field=notifications.fields.JSONField(default={}),
        ),
    ]
