# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-10-05 04:02
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0005_auto_20170814_1118'),
    ]

    operations = [
        migrations.RenameField(
            model_name='notification',
            old_name='recipent',
            new_name='recipient',
        ),
    ]
