"Notifications app config"

from django.apps import AppConfig


class NotificationsConfig(AppConfig):
    """App Config."""

    name = 'notifications'
    default_auto_field = 'django.db.models.AutoField'
